@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2007 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1047,7 +1047,7 @@ DXWindow::ErrorMessage()
 const char*
 DXWindow::DDErrorMessage(int code)
 {
-  const static char *error;
+  static const char *error;
   static char errormsg [1024];	
 
   switch (code) {
